pub struct Config {
pub min_length: u8,
pub min_length_nul: u8,
pub strict_nul: bool,
pub heuristic: Heuristic,
}Expand description
Configure the string finding heuristics.
Fields
min_length: u8Minimum string length to accept as a valid string.
min_length_nul: u8Minimum string length when there is a nul terminator. Can have a lower threshold as having a nul terminator increases confidence that this is a c string literal.
strict_nul: boolWhen true, requires any found string to be terminated by a nul terminator. A nul terminator increases confidence that this is indeed a c string literal.
heuristic: HeuristicHeuristic to use to validate sequences.
Implementations
Sourceimpl Config
impl Config
Sourcepub fn enumerate(self, base: u32, bytes: &[u8]) -> Enumerator<'_> ⓘ
pub fn enumerate(self, base: u32, bytes: &[u8]) -> Enumerator<'_> ⓘ
Constructs the enumerator with this configuration.
Given the base argument the relative virtual address of the bytes slice.